==> vue-components-1.5.6.tgz: package/lib/modals/src/Modal.vue.rd.js <==
import { useInjectStyle as p } from "../../shared/hooks/useInjectStyle.rd.js";
import { defineComponent as c, openBlock as l, createBlock as s, unref as i, mergeProps as k, isRef as C, withCtx as v, createElementVNode as f, normalizeClass as t, createVNode as $, renderSlot as d, createCommentVNode as h } from "vue";
import { useVModel as y } from "@vueuse/core";
import "../../node_modules/ant-design-vue/es/modal/index.rd.js";
/* empty css                                                          *//* empty css                                                              *//* empty css                                                               */import g from "./ModalFooter.vue.rd.js";
import w from "./ModalHeader.vue.rd.js";
import P from "./ModalPrimaryHeader.vue.rd.js";
import { modalProps as B } from "./props.rd.js";
import I from "../../node_modules/ant-design-vue/es/modal/style/index.css.rd.js";
import M from "./modal.scss.rd.js";
import "../../spinners/index.rd.js";
import T from "../../node_modules/ant-design-vue/es/modal/Modal.rd.js";
import V from "../../spinners/src/AbsoluteLoader.vue.rd.js";
const O = /* @__PURE__ */ c({
  __name: "Modal",
  props: B(),
  emits: ["update:visible", "cancel", "close", "accept"],
  setup(u, { emit: m }) {
    const b = u;
    p(I, "ant-modal"), p(M, "ant-modal-custom");
    const r = y(b, "visible");
    function a() {
      m("update:visible", !1), m("close");
    }
    return (e, o) => (l(), s(i(T), k({
      visible: i(r),
      "onUpdate:visible": o[2] || (o[2] = (n) => C(r) ? r.value = n : null),
      keyboard: e.keyboard,
      bodyStyle: { padding: "0px", overflow: "hidden" },
      footer: null,
      title: null,
      closeIcon: !1,
      afterClose: a,
      closable: !1,
      maskClosable: e.maskClosable
    }, e.$attrs), {
      default: v(() => [
        f("div", {
          class: t([[
            { "dark:border-1px dark:border-solid dark:border-slate-700": e.border },
            e.containerClass
          ], "z-10 overflow-hidden round-big bg-surface"])
        }, [
          $(i(V), {
            loading: e.loading,
            description: e.loadingDescription
          }, null, 8, ["loading", "description"]),
          e.$slots.header ? d(e.$slots, "header", { key: 0 }) : e.showHeader && e.primaryHeader ? (l(), s(P, {
            key: 1,
            title: e.headTitle,
            onClose: a
          }, null, 8, ["title"])) : e.showHeader ? (l(), s(w, {
            key: 2,
            hoverableClose: e.hoverableClose,
            headTitle: e.headTitle,
            showCloseIcon: e.showCloseIcon,
            onClose: a
          }, null, 8, ["hoverableClose", "headTitle", "showCloseIcon"])) : h("", !0),
          f("div", {
            class: t(["p-5 text-muted", { "p-0": e.noPadding }])
          }, [
            d(e.$slots, "default")
          ], 2),
          !e.$slots.footer && e.showFooter ? (l(), s(g, {
            key: 3,
            class: t(e.footerClass),
            okBtnProps: e.okBtnProps,
            cancelBtnProps: e.cancelBtnProps,
            onAccept: o[0] || (o[0] = (n) => e.$emit("accept")),
            onCancel: o[1] || (o[1] = (n) => e.$emit("cancel"))
          }, null, 8, ["class", "okBtnProps", "cancelBtnProps"])) : d(e.$slots, "footer", { key: 4 })
        ], 2)
      ]),
      _: 3
    }, 16, ["visible", "keyboard", "maskClosable"]));
  }
});
export {
  O as default
};

==> vue-components-1.5.8.tgz: package/lib/modals/src/Modal.vue.rd.js <==
import { useInjectStyle as f } from "../../shared/hooks/useInjectStyle.rd.js";
import { defineComponent as C, openBlock as l, createBlock as s, unref as t, mergeProps as c, isRef as k, withCtx as v, createElementVNode as u, normalizeClass as d, createVNode as $, renderSlot as m, createCommentVNode as h } from "vue";
import { useVModel as y } from "@vueuse/core";
import "../../node_modules/ant-design-vue/es/modal/index.rd.js";
/* empty css                                                          *//* empty css                                                              *//* empty css                                                               */import g from "./ModalFooter.vue.rd.js";
import w from "./ModalHeader.vue.rd.js";
import P from "./ModalPrimaryHeader.vue.rd.js";
import { modalProps as B } from "./props.rd.js";
import I from "../../node_modules/ant-design-vue/es/modal/style/index.css.rd.js";
import M from "./modal.scss.rd.js";
import "../../spinners/index.rd.js";
import T from "../../node_modules/ant-design-vue/es/modal/Modal.rd.js";
import V from "../../spinners/src/AbsoluteLoader.vue.rd.js";
const O = /* @__PURE__ */ C({
  __name: "Modal",
  props: B(),
  emits: ["update:visible", "cancel", "close", "accept"],
  setup(b, { emit: p }) {
    const r = b;
    f(I, "ant-modal"), f(M, "ant-modal-custom");
    const a = y(r, "visible");
    function n() {
      typeof r.beforeClose == "function" ? r.beforeClose() : (p("update:visible", !1), p("close"));
    }
    return (e, o) => (l(), s(t(T), c({
      visible: t(a),
      "onUpdate:visible": o[2] || (o[2] = (i) => k(a) ? a.value = i : null),
      keyboard: e.keyboard,
      bodyStyle: { padding: "0px", overflow: "hidden" },
      footer: null,
      title: null,
      closeIcon: !1,
      afterClose: n,
      closable: !1,
      maskClosable: e.maskClosable
    }, e.$attrs), {
      default: v(() => [
        u("div", {
          class: d([[
            { "dark:border-1px dark:border-solid dark:border-slate-700": e.border },
            e.containerClass
          ], "z-10 overflow-hidden round-big bg-surface"])
        }, [
          $(t(V), {
            loading: e.loading,
            description: e.loadingDescription
          }, null, 8, ["loading", "description"]),
          e.$slots.header ? m(e.$slots, "header", { key: 0 }) : e.showHeader && e.primaryHeader ? (l(), s(P, {
            key: 1,
            title: e.headTitle,
            onClose: n
          }, null, 8, ["title"])) : e.showHeader ? (l(), s(w, {
            key: 2,
            hoverableClose: e.hoverableClose,
            headTitle: e.headTitle,
            showCloseIcon: e.showCloseIcon,
            onClose: n
          }, null, 8, ["hoverableClose", "headTitle", "showCloseIcon"])) : h("", !0),
          u("div", {
            class: d(["p-5 text-muted", { "p-0": e.noPadding }])
          }, [
            m(e.$slots, "default")
          ], 2),
          !e.$slots.footer && e.showFooter ? (l(), s(g, {
            key: 3,
            class: d(e.footerClass),
            okBtnProps: e.okBtnProps,
            cancelBtnProps: e.cancelBtnProps,
            onAccept: o[0] || (o[0] = (i) => e.$emit("accept")),
            onCancel: o[1] || (o[1] = (i) => e.$emit("cancel"))
          }, null, 8, ["class", "okBtnProps", "cancelBtnProps"])) : m(e.$slots, "footer", { key: 4 })
        ], 2)
      ]),
      _: 3
    }, 16, ["visible", "keyboard", "maskClosable"]));
  }
});
export {
  O as default
};
